pub enum ParseStatus {
Ok,
Partial,
Failed,
}Expand description
Parse status for a parsed bibliography document.
Variants
Ok
The document parsed without diagnostics that affect recovered content.
Partial
The document contains useful parsed data plus recovered or failed blocks.
Failed
The document could not produce meaningful bibliography data.