DiagnosticCode

Struct DiagnosticCode 

pub struct DiagnosticCode(/* private fields */);
Stable machine-readable diagnostic code.

The initial parser diagnostic codes are: missing-entry-key, missing-field-separator, expected-field-name, empty-field-value, expected-value-atom, bad-field-boundary, bad-value-boundary, unclosed-entry, unclosed-braced-value, and unclosed-quoted-value.

Implementations

Source

impl DiagnosticCode

pub const PARSE_ERROR: Self

Generic parse error code used before finer-grained recovery classifies a failure.

pub const MISSING_ENTRY_KEY: Self

Entry body did not contain a citation key.

pub const MISSING_FIELD_SEPARATOR: Self

Expected a comma after an entry key or = after a field name.

pub const EXPECTED_FIELD_NAME: Self

Expected a field name inside an entry body.

pub const EMPTY_FIELD_VALUE: Self

Field separator was present but no value was provided.

pub const EXPECTED_VALUE_ATOM: Self

Expected a literal, number, variable, quoted value, or braced value.

pub const BAD_FIELD_BOUNDARY: Self

Expected a comma or entry close after a field value.

pub const BAD_VALUE_BOUNDARY: Self

Expected a value atom after a concatenation operator.

pub const UNCLOSED_ENTRY: Self

Entry ended before its closing delimiter was found.

pub const UNCLOSED_BRACED_VALUE: Self

Braced field value ended before its closing brace was found.

pub const UNCLOSED_QUOTED_VALUE: Self

Quoted field value ended before its closing quote was found.

pub const fn borrowed(code: &'static str) -> Self

Create a borrowed static diagnostic code.

pub fn custom(code: impl Into<String>) -> Self

Create an owned diagnostic code.

pub fn as_str(&self) -> &str

Return the diagnostic code as a string.