SourceSpan

Struct SourceSpan 

pub struct SourceSpan {
    pub source: Option<SourceId>,
    pub byte_start: usize,
    pub byte_end: usize,
    pub line: usize,
    pub column: usize,
    pub end_line: usize,
    pub end_column: usize,
}
Byte and line/column location for source-backed items.

Byte offsets are zero-based and half-open: byte_start..byte_end. Lines and columns are one-based. End line and column identify the position immediately after the final character in the span, so an empty span has the same start and end position.

Fields

source: Option<SourceId>

Source identifier, when the span came from a named parsed source.

byte_start: usize

Byte offset where the item starts.

byte_end: usize

Byte offset where the item ends.

line: usize

Line number where the item starts (1-indexed).

column: usize

Column number where the item starts (1-indexed).

end_line: usize

Line number immediately after the item ends (1-indexed).

end_column: usize

Column number immediately after the item ends (1-indexed).

Implementations

Source

impl SourceSpan

pub const fn new( byte_start: usize, byte_end: usize, line: usize, column: usize, ) -> Self

Create a new source span.

pub const fn with_end( byte_start: usize, byte_end: usize, line: usize, column: usize, end_line: usize, end_column: usize, ) -> Self

Create a new source span with explicit start and end positions.

pub const fn with_source(self, source: SourceId) -> Self

Return this span associated with a source identifier.

pub const fn len(self) -> usize

Return the byte length covered by this span.

pub const fn is_empty(self) -> bool

Return true when the span is empty.