pub fn document_to_string(document: &ParsedDocument<'_>) -> Result<String>Expand description
Convenience function to write a parsed document to a string.
pub fn document_to_string(document: &ParsedDocument<'_>) -> Result<String>Convenience function to write a parsed document to a string.