parse_date_parts

Function parse_date_parts 

pub fn parse_date_parts(input: &str) -> Result<DateParts, DateParseError>
Parse a common bibliography date shape into parts.

Supported input shapes are YYYY, YYYY-MM, and YYYY-MM-DD. Month names and BibTeX month abbreviations are accepted by entry helpers when a separate month field is combined with a year field.