DuplicateKeyGroup

Struct DuplicateKeyGroup 

pub struct DuplicateKeyGroup {
    pub key: String,
    pub occurrences: Vec<DuplicateKeyOccurrence>,
    pub cross_source: bool,
}
Duplicate citation key group with source provenance.

Fields

key: String

Citation key text.

occurrences: Vec<DuplicateKeyOccurrence>

Occurrences in corpus order.

cross_source: bool

true when occurrences come from more than one source.

Implementations

Source

impl DuplicateKeyGroup

pub const fn is_same_source(&self) -> bool

Return true when every occurrence is in the same source.