pub struct SourceSpan {
pub source: Option<SourceId>,
pub byte_start: usize,
pub byte_end: usize,
pub line: usize,
pub column: usize,
pub end_line: usize,
pub end_column: usize,
}Expand description
Byte and line/column location for source-backed items.
Byte offsets are zero-based and half-open: byte_start..byte_end.
Lines and columns are one-based. End line and column identify the position
immediately after the final character in the span, so an empty span has the
same start and end position.
Fields
source: Option<SourceId>Source identifier, when the span came from a named parsed source.
byte_start: usizeByte offset where the item starts.
byte_end: usizeByte offset where the item ends.
line: usizeLine number where the item starts (1-indexed).
column: usizeColumn number where the item starts (1-indexed).
end_line: usizeLine number immediately after the item ends (1-indexed).
end_column: usizeColumn number immediately after the item ends (1-indexed).
Implementations
Sourceimpl SourceSpan
impl SourceSpan
Sourcepub const fn new(
byte_start: usize,
byte_end: usize,
line: usize,
column: usize,
) -> Self
pub const fn new( byte_start: usize, byte_end: usize, line: usize, column: usize, ) -> Self
Create a new source span.
Sourcepub const fn with_end(
byte_start: usize,
byte_end: usize,
line: usize,
column: usize,
end_line: usize,
end_column: usize,
) -> Self
pub const fn with_end( byte_start: usize, byte_end: usize, line: usize, column: usize, end_line: usize, end_column: usize, ) -> Self
Create a new source span with explicit start and end positions.
Sourcepub const fn with_source(self, source: SourceId) -> Self
pub const fn with_source(self, source: SourceId) -> Self
Return this span associated with a source identifier.