EntryType

Enum EntryType 

pub enum EntryType<'a> {
Show 32 variants Article, Book, Booklet, MvBook, InBook, BookInBook, SuppBook, Collection, MvCollection, InCollection, SuppCollection, InProceedings, Proceedings, MvProceedings, Reference, InReference, Manual, MastersThesis, PhdThesis, Thesis, TechReport, Report, Patent, Periodical, Online, Software, Dataset, Set, XData, Unpublished, Misc, Custom(Cow<'a, str>),
}
BibTeX entry type

Variants



Article

Article from a journal



Book

Book with publisher



Booklet

Booklet without a named publisher



MvBook

A multi-volume book (biblatex)



InBook

Part of a book



BookInBook

A self-contained book part published as a book (biblatex)



SuppBook

Supplemental material in a book (biblatex)



Collection

A collection with its own title



MvCollection

A multi-volume collection (biblatex)



InCollection

A contribution to a collection



SuppCollection

Supplemental material in a collection (biblatex)



InProceedings

Article in conference proceedings



Proceedings

Conference proceedings



MvProceedings

Multi-volume proceedings (biblatex)



Reference

A reference work (biblatex)



InReference

A contribution to a reference work (biblatex)



Manual

Technical documentation or manual



MastersThesis

Master’s thesis



PhdThesis

PhD thesis



Thesis

Generic thesis (biblatex)



TechReport

Technical report



Report

Generic report (biblatex)



Patent

Patent or patent request (biblatex)



Periodical

Periodical issue (biblatex)



Online

Online resource (biblatex)



Software

Software artifact (biblatex and common repository exports)



Dataset

Dataset artifact (biblatex and common repository exports)



Set

Entry set (biblatex)



XData

Reusable data-only entry (biblatex)



Unpublished

Unpublished work



Misc

Miscellaneous



Custom(Cow<'a, str>)

Custom entry type

Implementations

Source

impl<'a> EntryType<'a>

pub fn parse(s: &'a str) -> Self

Parse from string (case-insensitive)

pub const fn required_fields(&self) -> &'static [&'static str]

Get required fields for this entry type

pub const fn required_field_groups(&self) -> &'static [&'static [&'static str]]

Get required field groups for validation.

Each inner group is an OR-list. For example, ["author", "editor"] means either field satisfies that requirement.

pub fn canonical_name(&self) -> &str

Return the canonical lowercase entry type name.

pub const fn aliases(&self) -> &'static [&'static str]

Return common aliases that parse to this entry type.

pub const fn is_classic_bibtex(&self) -> bool

Return true for the classic BibTeX entry types.

pub const fn is_extended(&self) -> bool

Return true for entry types that are specific to BibLaTeX or common repository exports.

pub fn into_owned(self) -> EntryType<'static>

Convert to owned version