Value

Enum Value 

pub enum Value<'a> {
    Literal(Cow<'a, str>),
    Number(i64),
    Concat(Box<[Self]>),
    Variable(Cow<'a, str>),
}
A value in a BibTeX field

Memory Optimization

Concatenation parts are stored out of line so the common literal, number, and variable variants stay compact.

Variants



Literal(Cow<'a, str>)

String literal



Number(i64)

Number literal



Concat(Box<[Self]>)

Concatenated values (boxed to reduce enum size)



Variable(Cow<'a, str>)

Variable reference

Implementations

Source

impl Value<'_>

pub fn as_str(&self) -> Option<&str>

Get the value as a string (if it’s a simple literal)

pub fn expand(&self, strings: &AHashMap<&str, Value<'_>>) -> String

Expand variables and concatenations to get final string

pub fn into_owned(self) -> Value<'static>

Convert to owned version